OrganizationUser

Struct OrganizationUser 

pub struct OrganizationUser {
Show 14 fields pub id: Option<Uuid>, pub organization_id: Option<Uuid>, pub user_id: Option<Uuid>, pub email: Option<String>, pub key: Option<String>, pub reset_password_key: Option<String>, pub status: Option<OrganizationUserStatusType>, pub type: Option<OrganizationUserType>, pub external_id: Option<String>, pub creation_date: Option<String>, pub revision_date: Option<String>, pub permissions: Option<String>, pub access_secrets_manager: Option<bool>, pub revocation_reason: Option<RevocationReason>,
}
OrganizationUser : An association table between one Bit.Core.Entities.User and one Bit.Core.AdminConsole.Entities.Organization, representing that user’s membership in the organization. "Member" refers to the OrganizationUser object.

Fields

id: Option<Uuid>

A unique random identifier.

organization_id: Option<Uuid>

The ID of the Organization that the user is a member of.

user_id: Option<Uuid>

The ID of the User that is the member. This is NULL if the Status is Invited (or Invited and then Revoked), because it is not linked to a specific User yet.

email: Option<String>

The email address of the user invited to the organization. This is NULL if the Status is not Invited (or Invited and then Revoked), because in that case the OrganizationUser is linked to a User and the email is stored on the User object.

key: Option<String>

The Organization symmetric key encrypted with the User’s public key. NULL if the user is not in a Confirmed (or Confirmed and then Revoked) status.

reset_password_key: Option<String>

The User’s symmetric key encrypted with the Organization’s public key. NULL if the OrganizationUser is not enrolled in account recovery.

status: Option<OrganizationUserStatusType>type: Option<OrganizationUserType>external_id: Option<String>

An ID used to identify the OrganizationUser with an external directory service. Used by Directory Connector and SCIM.

creation_date: Option<String>

The date the OrganizationUser was created, i.e. when the User was first invited to the Organization.

revision_date: Option<String>

The last date the OrganizationUser entry was updated.

permissions: Option<String>

A json blob representing the Bit.Core.Models.Data.Permissions of the OrganizationUser if they are a Custom user role (i.e. the Bit.Core.Enums.OrganizationUserType is Custom). MAY be NULL if they are not a custom user, but this is not guaranteed; do not use this to determine their role.

access_secrets_manager: Option<bool>

True if the User has access to Secrets Manager for this Organization, false otherwise.

revocation_reason: Option<RevocationReason>

Implementations

Source

impl OrganizationUser

pub fn new() -> OrganizationUser

An association table between one Bit.Core.Entities.User and one Bit.Core.AdminConsole.Entities.Organization, representing that user’s membership in the organization. "Member" refers to the OrganizationUser object.